@@ -1,5 +1,4 @@
 // -*- c++ -*-
-/* $Id$ */
 
 /* exceptionhandler.cc
  *
@@ -20,19 +19,14 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <glib.h>
-#include <exception>
-#include <list>
-
 #include <glibmmconfig.h>
 #include <glibmm/error.h>
 #include <glibmm/exceptionhandler.h>
 #include <glibmm/thread.h>
+#include <glib.h>
+#include <exception>
+#include <list>
 
-GLIBMM_USING_STD(exception)
-GLIBMM_USING_STD(list)
-
-#ifdef GLIBMM_EXCEPTIONS_ENABLED
 
 namespace
 {
@@ -158,6 +152,5 @@ void exception_handlers_invoke() throw()
 
 } // namespace Glib
 
-#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 
